| increment | R Documentation |
Calculation of annal and mean increment of stand volume based on growth dynamic data of stand volume
increment(Vpre)
Vpre |
Growth dynamic data of stand volume, the data format is the data.frame. |
Growth dynamic data of stand volume, the data format is the data.frame.
Data included the annal and mean increment of stand volume.
Zongzheng Chai, chaizz@126.com
NULL
Vdyn<-estV(b0=2.0137,b1=0.0795,b2=-16.9509,b3=0.7924,
a0=1.1656,a1=0.1376,
B1=3.1,t1=10,t2=11:100,SI=12)
increment(Vpre=Vdyn$Value)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.